import * as prompts from "@clack/prompts";
import chalk from "chalk";
import { parseArgs } from "node:util";
import { fromZodError } from "zod-validation-error";
import { createRerunSuggestion } from "../create/createRerunSuggestion.js";
import { create } from "../create/index.js";
import { initialize } from "../initialize/index.js";
import { migrate } from "../migrate/index.js";
import { logLine } from "../shared/cli/lines.js";
import { StatusCodes } from "../shared/codes.js";
import { logHelpText } from "./help.js";
import { getVersionFromPackageJson } from "./packageJson.js";
import { promptForMode } from "./promptForMode.js";
const operationMessage = (verb) => `Operation ${verb}. Exiting - maybe another time? \u{1F44B}`;
async function bin(args) {
  console.clear();
  const version = await getVersionFromPackageJson();
  const introPrompts = [
    chalk.greenBright(`\u2728 Welcome to`),
    chalk.bgGreenBright.black(`create-typescript-app`),
    chalk.greenBright(`${version}! \u2728`)
  ].join(" ");
  const introWarnings = [
    chalk.yellow(
      "\u26A0\uFE0F This template is early stage, opinionated, and not endorsed by the TypeScript team. \u26A0\uFE0F"
    ),
    chalk.yellow(
      "\u26A0\uFE0F If any tooling it sets displeases you, you can always remove that portion manually. \u26A0\uFE0F"
    )
  ];
  const { values } = parseArgs({
    args,
    options: {
      help: {
        short: "h",
        type: "boolean"
      },
      mode: { type: "string" }
    },
    strict: false
  });
  const help = values.help;
  if (help) {
    logHelpText([introPrompts, ...introWarnings]);
    return 0;
  }
  prompts.intro(introPrompts);
  logLine();
  logLine(introWarnings[0]);
  logLine(introWarnings[1]);
  const { mode, options: promptedOptions } = await promptForMode(values.mode);
  if (typeof mode !== "string") {
    prompts.outro(chalk.red(mode?.message ?? operationMessage("cancelled")));
    return 1;
  }
  const runners = { create, initialize, migrate };
  const { code, error, options } = await runners[mode](args, promptedOptions);
  prompts.log.info(
    [
      chalk.italic(`Tip: to run again with the same input values, use:`),
      chalk.blue(createRerunSuggestion(options))
    ].join(" ")
  );
  if (code) {
    logLine();
    if (error) {
      logLine(
        chalk.red(typeof error === "string" ? error : fromZodError(error))
      );
      logLine();
    }
    prompts.cancel(
      code === StatusCodes.Cancelled ? operationMessage("cancelled") : operationMessage("failed")
    );
  }
  return code;
}
export {
  bin
};
//# sourceMappingURL=index.js.map